pitchtools.NumberedChromaticPitchClassVector
============================================

.. autoclass:: abjad.tools.pitchtools.NumberedChromaticPitchClassVector
   :members:
   :undoc-members:
   :show-inheritance:
